Containing python package egp-py

## Get Started

### Install

```shell
pip install scale-egp-py
```

### Usage

```python
from egp_eval import ...
```

## Documentation

Documentation is available soon
